@@ -12,15 +12,16 @@ class asciii():
     ]
     im_map=""
 
-    def __init__(self,pattern=0,max_size=0):
+    def __init__(self,pattern=0,max_size=0,shift=0):
         if isinstance(pattern,str):
             self.cols=pattern
         else:
-            self.cols=self.cols_patterns[pattern]
+            self.cols=self.cols_patterns[int(pattern)]
         if max_size!=0:
             self.maxs(max_size)
         else:
             self.maxs()
+        self.shift=shift
     
     def maxs(self,size=140):
         self.max_size=(size,size)
@@ -54,7 +55,7 @@ class asciii():
             if y%2==1:
                 for x in range(width):
                     r, g, b = rgb_im.getpixel((x, y))
-                    s=(r+g+b)/3
+                    s=min(((r+g+b)/3)+self.shift,255)
                     s=self.remap(s,0,255,0,len(self.cols)-1)
                     #self.im_map+=self.colored(r,g,b,self.cols[s])
                     if self.cols=="":
@@ -71,5 +72,5 @@ if __name__=="__main__":
     args=sys.argv
     args.append(0)
     args.append(0)
-    print(asciii(int(args[2]),int(args[3])).product(args[1]))
+    print(asciii(args[2],int(args[3]),int(args[4])).product(args[1]))
 ####py ita.py filename pattern size
\ No newline at end of file
